.utilitySwitch: Utility Input Switch
Description
Utility functions
Usage
.utilitySwitch(pux = NULL, uxs = NULL, rxy = NULL, sr = NULL)
Arguments
pux
The expected average criterion score of selected applicants.
uxs
The average predicter score of those selected
rxy
The correlation between the predictor composite and the criterion.
sr
A selection ratio or a vector of selection ratios.
Value
The expected average criterion score of selected applicants.